==> haskell-gauge-0.2.4-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gauge.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gauge
version: 0.2.4
id: gauge-0.2.4-FOkPKasY8PI5z5NMCuLSlP
key: gauge-0.2.4-FOkPKasY8PI5z5NMCuLSlP
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/vincenthz/hs-gauge
synopsis: small framework for performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
category: Development, Performance, Testing, Benchmarking
abi: 7faf772e5808a026c5399c3cfad2a6ae
exposed: True
exposed-modules:
    Gauge Gauge.Analysis Gauge.Benchmark Gauge.Main Gauge.Main.Options
hidden-modules: Gauge.IO.Printf Gauge.Measurement Gauge.Monad
                Gauge.ListMap Gauge.Time Gauge.Optional Gauge.CSV Gauge.Format
                Gauge.Source.RUsage Gauge.Source.GC Gauge.Source.Time
                System.Random.MWC Paths_gauge Statistics.Distribution
                Statistics.Distribution.Normal Statistics.Function
                Statistics.Internal Statistics.Math.RootFinding Statistics.Matrix
                Statistics.Matrix.Algorithms Statistics.Matrix.Mutable
                Statistics.Matrix.Types Statistics.Quantile Statistics.Regression
                Statistics.Resampling Statistics.Resampling.Bootstrap
                Statistics.Sample Statistics.Sample.Histogram
                Statistics.Sample.Internal Statistics.Sample.KernelDensity
                Statistics.Transform Statistics.Types Statistics.Types.Internal
                Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
                Numeric.SpecFunctions Numeric.SpecFunctions.Internal Numeric.Sum
import-dirs: /usr/lib/ghc-8.6.3/site-local/gauge-0.2.4
library-dirs: /usr/lib/ghc-8.6.3/site-local/gauge-0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/gauge-0.2.4
hs-libraries: HSgauge-0.2.4-FOkPKasY8PI5z5NMCuLSlP
depends:
    base-4.12.0.0 basement-0.0.10-2z2JaOuy7fVLQL3Bi1dEbr
    deepseq-1.4.4.0 directory-1.3.3.0 process-1.6.3.0
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-gauge/html/gauge.haddock
haddock-html: /usr/share/doc/haskell-gauge/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gauge-0.2.4-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gauge.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gauge
version: 0.2.4
id: gauge-0.2.4-3hpc4AtoqwL6ug2SEopLaq
key: gauge-0.2.4-3hpc4AtoqwL6ug2SEopLaq
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/vincenthz/hs-gauge
synopsis: small framework for performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
category: Development, Performance, Testing, Benchmarking
abi: d587bf2b8c734bfe75dd0fdbf6eba0c1
exposed: True
exposed-modules:
    Gauge Gauge.Analysis Gauge.Benchmark Gauge.Main Gauge.Main.Options
hidden-modules: Gauge.IO.Printf Gauge.Measurement Gauge.Monad
                Gauge.ListMap Gauge.Time Gauge.Optional Gauge.CSV Gauge.Format
                Gauge.Source.RUsage Gauge.Source.GC Gauge.Source.Time
                System.Random.MWC Paths_gauge Statistics.Distribution
                Statistics.Distribution.Normal Statistics.Function
                Statistics.Internal Statistics.Math.RootFinding Statistics.Matrix
                Statistics.Matrix.Algorithms Statistics.Matrix.Mutable
                Statistics.Matrix.Types Statistics.Quantile Statistics.Regression
                Statistics.Resampling Statistics.Resampling.Bootstrap
                Statistics.Sample Statistics.Sample.Histogram
                Statistics.Sample.Internal Statistics.Sample.KernelDensity
                Statistics.Transform Statistics.Types Statistics.Types.Internal
                Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
                Numeric.SpecFunctions Numeric.SpecFunctions.Internal Numeric.Sum
import-dirs: /usr/lib/ghc-8.6.4/site-local/gauge-0.2.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/gauge-0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/gauge-0.2.4
hs-libraries: HSgauge-0.2.4-3hpc4AtoqwL6ug2SEopLaq
depends:
    base-4.12.0.0 basement-0.0.10-2z2JaOuy7fVLQL3Bi1dEbr
    deepseq-1.4.4.0 directory-1.3.3.0 process-1.6.5.0
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-gauge/html/gauge.haddock
haddock-html: /usr/share/doc/haskell-gauge/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
